@@ -31,6 +31,7 @@ sub new {
     elsif(defined $self->_verifyflag and $self->_verifyflag & 8){
         $self->category("公众号");
     }
+    else{$self->category("好友");}
     $self->uid("") if not $self->uid;
     $self;
 }
@@ -84,4 +85,8 @@ sub set_markname {
     my $self = shift;
     $self->client->set_markname($self,@_);
 }
+sub stick{
+    my $self = shift;
+    $self->client->stick($self,@_);
+}
 1;
