@@ -1,6 +1,8 @@
 package Mojo::Weixin::Plugin::Beauty;
 our $PRIORITY = 95;
 use Storable qw(retrieve nstore);
+use Encode qw();
+use Mojo::Util qw();
 use List::Util qw(first);
 sub call{
     my $client = shift;
@@ -32,8 +34,11 @@ sub call{
         }
         my $html = $client->http_get($url);
         if(defined $html){
-            if($html=~m#\Qapp.page["board"]\E\s*=\s*(.*?);#){
+            if($html=~m#\Qapp.page["board"]\E\s*=\s*(.*);\s?#){
                 my $data = $1;
+                $data=~s/&nbsp;/ /g;
+                my $unicode_data = Mojo::Util::html_unescape(Encode::decode("utf8",$data));
+                $data = Encode::encode("utf8",$unicode_data);
                 my $json = $client->from_json($data);
                 if(defined $json and defined  $json->{pins}){
                     for(@{ $json->{pins} }){
