@@ -66,7 +66,19 @@ sub spurt {
 sub from_json{
     my $self = shift;
     my $r = eval{
-        Mojo::JSON::from_json(@_);
+        if($self->json_codec_mode == 0){
+            my $json = Mojo::JSON::from_json(@_);
+            $json;
+        }
+        elsif($self->json_codec_mode == 1){
+            my $json  = Mojo::JSON::decode_json(@_);
+            $self->reform($json);
+            $json;
+        }
+        else{
+            my $json = Mojo::JSON::from_json(@_);
+            $json;
+        }
     };
     if($@){
         $self->warn($@);
@@ -317,4 +329,12 @@ sub print {
     $self;
 }
 
+sub stdout_line {
+    my $self = shift;
+    my $data = $_[0];
+    $data=~s/[\r\n]+$//s;
+    STDOUT->printflush($data . "\n");
+    $self;
+}
+
 1;
